@@ -1,21 +1,19 @@
-#
 #    Filters.pm - Common filters for use in Data::FormValidator.
-#
 #    This file is part of Data::FormValidator.
 #
 #    Author: Francis J. Lacoste <francis.lacoste@iNsu.COM>
+#    Maintainer: Mark Stosberg <mark@summersault.com>
 #
 #    Copyright (C) 1999,2000 iNsu Innovations Inc.
 #
-#    This program is free software; you can redistribute it and/or modify
-#    it under the terms same terms as perl itself.
-#
+#    This program is free software; you can redistribute it and/or modify 
+#    it under the terms same terms as perl itself.  
 
 package Data::FormValidator::Filters;
 use strict;
 use vars qw/$AUTOLOAD @ISA @EXPORT_OK %EXPORT_TAGS $VERSION/;
 
-$VERSION = 4.00;
+$VERSION = 4.1;
 
 require Exporter;
 @ISA = qw(Exporter);
@@ -37,6 +35,7 @@ require Exporter;
 	filter_trim
 	filter_uc
 	filter_ucfirst
+    FV_split
 );
 
 %EXPORT_TAGS = (
@@ -51,24 +50,47 @@ sub DESTROY {}
 
 Data::FormValidator::Filters - Basic set of filters available in an Data::FormValidator profile.
 
-
 =head1 SYNOPSIS
 
     use Data::FormValidator;
 
-    my $validator = new Data::FormValidator( "/home/user/input_profiles.pl" );
-    my $results = $validator->check(  \%fdat, "customer_infos" );
+    %profile = (
+        filters => 'trim',
+        ...
+    );
+
+    my $results = Data::FormValidator->check(  \%data, \%profile );
 
 =head1 DESCRIPTION
 
 These are the builtin filters which may be specified as a name in the
-I<filters> and I<field_filters> parameters of the input profile. You may
-also call these functions directly through the procedural interface by 
-either importing them directly or importing the whole I<:filters> group. For
-example, if you want to access the I<trim> function directly, you could either do:
+I<filters>, I<field_filters>, and I<field_filter_regexp_map> parameters of the
+input profile. 
+
+Filters are applied as the first step of validation, possibily modifying a copy
+of the validation before any constraints are checked. 
+
+=head1 RECOMMENDED USE
+
+As a long time maintainer and user of Data::FormValidator, I recommend that
+filters be used with caution. They are immediately modifying the input
+provided, so the original data is lost. The few I recommend include C<trim>,
+which removes leading and trailing whitespace. I have this turned on by default 
+by using L<CGI::Application::Plugin::ValidateRM>. It's also generally safe to use
+the C<lc> and C<uc> filters if you need that kind of data transformation. 
+
+Beyond simple filters, I recommend transforming the C<"valid"> hash returned
+from validation if further changes are needed. 
+
+=head1 PROCEDURAL INTERFACE
+
+You may also call these functions directly through the
+procedural interface by either importing them directly or importing the whole
+I<:filters> group. For example, if you want to access the I<trim> function
+directly, you could either do:
 
     use Data::FormValidator::Filters (qw/filter_trim/);
-    or
+    # or
     use Data::FormValidator::Filters (qw/:filters/);
 
     $string = filter_trim($string);
@@ -76,9 +98,46 @@ example, if you want to access the I<trim> function directly, you could either d
 Notice that when you call filters directly, you'll need to prefix the filter name with
 "filter_".
 
-=over
+=head1 THE FILTERS
 
-=item trim
+=head2 FV_split
+
+  use Data::FormValidator::Filters qw(FV_split);
+
+  # Validate every e-mail in a comma separated list 
+
+  field_filters => {
+     several_emails  => FV_split(qr/\s*,\s*/),
+
+     # Any pattern that can be used by the 'split' builtin works. 
+     tab_sep_field   => FV_split('\t'),
+  },
+  constraint_methods => {
+    several_emails => email(),
+  },
+
+With this filter, you can split a field into multiple values. The constraint for
+the field will then be applied to every value. 
+
+This filter has a different naming convention because it is a higher-order
+function.  Rather than returning a value directly, it returns a code reference
+to a standard Data::FormValidator filter. 
+
+After successfully being validated the values will appear as an arrayref.
+
+=cut
+
+sub FV_split {
+    my $splitter = shift || die "nothing to split on!";
+    return sub { 
+        my $value = shift;
+        return undef unless defined $value;
+        my @a = split $splitter, $value; 
+        return \@a; 
+    };
+}
+
+=head2 trim
 
 Remove white space at the front and end of the fields.
 
@@ -99,7 +158,7 @@ sub filter_trim {
 
 =pod
 
-=item strip
+=head2 strip
 
 Runs of white space are replaced by a single space.
 
@@ -117,7 +176,7 @@ sub filter_strip {
 
 =pod
 
-=item digit
+=head2 digit
 
 Remove non digits characters from the input.
 
@@ -134,7 +193,7 @@ sub filter_digit {
 
 =pod
 
-=item alphanum
+=head2 alphanum
 
 Remove non alphanumerical characters from the input.
 
@@ -149,7 +208,7 @@ sub filter_alphanum {
 
 =pod
 
-=item integer
+=head2 integer
 
 Extract from its input a valid integer number.
 
@@ -165,10 +224,12 @@ sub filter_integer {
 
 =pod
 
-=item pos_integer
+=head2 pos_integer
 
 Extract from its input a valid positive integer number.
 
+Bugs: This filter won't extract "9" from "a9+", it will instead extract "9+"
+
 =cut
 
 sub filter_pos_integer {
@@ -181,10 +242,13 @@ sub filter_pos_integer {
 
 =pod
 
-=item neg_integer
+=head2 neg_integer
 
 Extract from its input a valid negative integer number.
 
+Bugs: This filter will currently filter the case of "a9-" to become "9-",
+which it should leave it alone. 
+
 =cut
 
 sub filter_neg_integer {
@@ -197,10 +261,12 @@ sub filter_neg_integer {
 
 =pod
 
-=item decimal
+=head2 decimal
 
 Extract from its input a valid decimal number.
 
+Bugs: Given "1,000.23", it will currently return "1.000.23"
+
 =cut
 
 sub filter_decimal {
@@ -215,10 +281,12 @@ sub filter_decimal {
 
 =pod
 
-=item pos_decimal
+=head2 pos_decimal
 
 Extract from its input a valid positive decimal number.
 
+Bugs: Given "1,000.23", it will currently return "1.000.23"
+
 =cut
 
 sub filter_pos_decimal {
@@ -233,10 +301,12 @@ sub filter_pos_decimal {
 
 =pod
 
-=item neg_decimal
+=head2 neg_decimal
 
 Extract from its input a valid negative decimal number.
 
+Bugs: Given "1,000.23", it will currently return "1.000.23"
+
 =cut
 
 sub filter_neg_decimal {
@@ -251,10 +321,12 @@ sub filter_neg_decimal {
 
 =pod
 
-=item dollars
+=head2 dollars
 
 Extract from its input a valid number to express dollars like currency.
 
+Bugs: This filter won't currently remove trailing numbers like "1.234".
+
 =cut
 
 sub filter_dollars {
@@ -268,7 +340,7 @@ sub filter_dollars {
 
 =pod
 
-=item phone
+=head2 phone
 
 Filters out characters which aren't valid for an phone number. (Only
 accept digits [0-9], space, comma, minus, parenthesis, period and pound [#].)
@@ -284,7 +356,7 @@ sub filter_phone {
 
 =pod
 
-=item sql_wildcard
+=head2 sql_wildcard
 
 Transforms shell glob wildcard (*) to the SQL like wildcard (%).
 
@@ -299,7 +371,7 @@ sub filter_sql_wildcard {
 
 =pod
 
-=item quotemeta
+=head2 quotemeta
 
 Calls the quotemeta (quote non alphanumeric character) builtin on its
 input.
@@ -313,7 +385,7 @@ sub filter_quotemeta {
 
 =pod
 
-=item lc
+=head2 lc
 
 Calls the lc (convert to lowercase) builtin on its input.
 
@@ -326,7 +398,7 @@ sub filter_lc {
 
 =pod
 
-=item uc
+=head2 uc
 
 Calls the uc (convert to uppercase) builtin on its input.
 
@@ -339,7 +411,7 @@ sub filter_uc {
 
 =pod
 
-=item ucfirst
+=head2 ucfirst
 
 Calls the ucfirst (Uppercase first letter) builtin on its input.
 
@@ -355,13 +427,9 @@ sub filter_ucfirst {
 
 __END__
 
-=pod
-
-=back
-
 =head1 SEE ALSO
 
-=over
+=over 4
 
 =item o
 
